# Changelog

All notable changes to this project will be documented in this file.

## [Unreleased]

### Added 

- Support for specifying absolute/relative path to app executable file instead of app_dir and relative app file separately
- Log files - option to append or overwrite files.

### Fixed

- Add getters/setters to UniversalBatchExecuter class.

## [0.0.4] - 2021-02-16

### Fixed

- Error message shwowing when incorrect data in config.json
- Some minor changes to the project structure.
- Copyright sign in README.md

## [0.0.3] - 2021-02-15

### Added

- README.md file.
- This CHANGELOG.md file.
- LICENSE.txt file.
- MANIFEST.in file.
- Made PyPi Package.

## [0.0.2] - 2021-02-14

### Added

- Class UniversalBatchExecuter, where all the data is stored.
- Support for reading json config file.
- Basic argparse support.

## [0.0.1] - 2021-01-29

### Added

- Made environment, requirements.txt file
- First, initial version of the project